aboutsummaryrefslogtreecommitdiffstats
path: root/include/llvm/CodeGen/ScheduleDAGInstrs.h
diff options
context:
space:
mode:
authorDan Gohman <gohman@apple.com>2008-12-23 18:36:58 +0000
committerDan Gohman <gohman@apple.com>2008-12-23 18:36:58 +0000
commitc9a5b9e38b442c2ae6b115213a07df3fcd14708d (patch)
tree13a3c0ce02152eae878387b3afa36cebd8aadda7 /include/llvm/CodeGen/ScheduleDAGInstrs.h
parent1bda0541f0ca613179052a203a62c2d36d9c5a46 (diff)
downloadexternal_llvm-c9a5b9e38b442c2ae6b115213a07df3fcd14708d.zip
external_llvm-c9a5b9e38b442c2ae6b115213a07df3fcd14708d.tar.gz
external_llvm-c9a5b9e38b442c2ae6b115213a07df3fcd14708d.tar.bz2
Rename BuildSchedUnits to BuildSchedGraph, and refactor the
code in ScheduleDAGSDNodes' BuildSchedGraph into separate functions. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@61376 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm/CodeGen/ScheduleDAGInstrs.h')
-rw-r--r--include/llvm/CodeGen/ScheduleDAGInstrs.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/llvm/CodeGen/ScheduleDAGInstrs.h b/include/llvm/CodeGen/ScheduleDAGInstrs.h
index cfea3e0..96d3f0f 100644
--- a/include/llvm/CodeGen/ScheduleDAGInstrs.h
+++ b/include/llvm/CodeGen/ScheduleDAGInstrs.h
@@ -45,9 +45,9 @@ namespace llvm {
return &SUnits.back();
}
/// BuildSchedUnits - Build SUnits from the MachineBasicBlock that we are
/// input.
- virtual void BuildSchedUnits();
+ virtual void BuildSchedGraph();
/// ComputeLatency - Compute node latency.
///
@@ -45,9 +45,9 @@ namespace llvm {
return &SUnits.back();
}
- /// BuildSchedUnits - Build SUnits from the MachineBasicBlock that we are
+ /// BuildSchedGraph - Build SUnits from the MachineBasicBlock that we are
/// input.